kvarn_async::prelude::compact_str::core::any

Struct TypeId

1.6.0 · source
pub struct TypeId { /* private fields */ }
A TypeId represents a globally unique identifier for a type.

Each TypeId is an opaque object which does not allow inspection of what’s inside but does allow basic operations such as cloning, comparison, printing, and showing.

A TypeId is currently only available for types which ascribe to 'static, but this limitation may be removed in the future.

While TypeId implements Hash, PartialOrd, and Ord, it is worth noting that the hashes and ordering will vary between Rust releases. Beware of relying on them inside of your code!

Implementations

source

impl TypeId

1.0.0 (const: unstable) · source

pub fn of<T>() -> TypeId
where T: 'static + ?Sized,

Returns the TypeId of the type this generic function has been instantiated with.

Examples
use std::any::{Any, TypeId};

fn is_string<T: